@@ -26,9 +26,11 @@ G_BEGIN_DECLS
 #define SN_TYPE_BACKEND (sn_backend_get_type ())
 G_DECLARE_FINAL_TYPE (SnBackend, sn_backend, SN, BACKEND, GObject)
 
-SnBackend             *sn_backend_new                          (void);
+SnBackend *
+sn_backend_new (void);
 
-void                   sn_backend_start                        (SnBackend               *backend);
+void
+sn_backend_start (SnBackend *backend);
 
 G_END_DECLS
 
