@@ -93,7 +93,7 @@ sn_plugin_init (SnPlugin *plugin)
 #endif
   plugin->idle_startup = 0;
   plugin->names_ordered = NULL;
-  plugin->names_hidden = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
+  plugin->names_hidden = NULL;
 
   /* Statusnotifier init */
   plugin->item = NULL;
@@ -180,6 +180,9 @@ sn_plugin_mode_changed (XfcePanelPlugin *panel_plugin,
                                                         : GTK_ORIENTATION_HORIZONTAL;
 
   sn_config_set_orientation (plugin->config, panel_orientation, orientation);
+
+  gtk_orientable_set_orientation (GTK_ORIENTABLE (plugin->box), panel_orientation);
+
 #ifdef ENABLE_X11
   if (plugin->systray_box != NULL)
     systray_plugin_orientation_changed (panel_plugin, panel_orientation);
