@@ -439,6 +439,8 @@ window_menu_plugin_screen_changed (GtkWidget *widget,
   /* set the new screen */
   plugin->screen = screen;
   manager = xfw_screen_get_workspace_manager (screen);
+
+  /* window<->workspace association only works on X11, where there is only one workspace group */
   plugin->workspace_group = xfw_workspace_manager_list_workspace_groups (manager)->data;
 
   /* connect signal to monitor this screen */
@@ -867,11 +869,22 @@ static void
 window_menu_plugin_workspace_add (GtkWidget *mi,
                                   WindowMenuPlugin *plugin)
 {
+  GdkMonitor *monitor;
+  GList *groups;
+
   panel_return_if_fail (WINDOW_MENU_IS_PLUGIN (plugin));
   panel_return_if_fail (XFW_IS_WORKSPACE_GROUP (plugin->workspace_group));
 
+  /* adding/removing workspaces is also available on wayland and it seems reasonable
+   * to do it on the last workspace group for the monitor the plugin is on;
+   * see also: window_menu_plugin_menu_new() */
+  monitor = panel_utils_get_monitor_at_widget (GTK_WIDGET (plugin));
+  groups = panel_utils_list_workspace_groups_for_monitor (plugin->screen, monitor);
+
   /* increase the number of workspaces */
-  xfw_workspace_group_create_workspace (plugin->workspace_group, NULL, NULL);
+  xfw_workspace_group_create_workspace (g_list_last (groups)->data, NULL, NULL);
+
+  g_list_free (groups);
 }
 
 
@@ -881,12 +894,23 @@ window_menu_plugin_workspace_remove (GtkWidget *mi,
                                      WindowMenuPlugin *plugin)
 {
   XfwWorkspace *workspace;
+  GdkMonitor *monitor;
+  GList *groups;
+
   panel_return_if_fail (WINDOW_MENU_IS_PLUGIN (plugin));
   panel_return_if_fail (XFW_IS_WORKSPACE_GROUP (plugin->workspace_group));
 
+  /* adding/removing workspaces is also available on wayland and it seems reasonable
+   * to do it on the last workspace group for the monitor the plugin is on;
+   * see also: window_menu_plugin_menu_new() */
+  monitor = panel_utils_get_monitor_at_widget (GTK_WIDGET (plugin));
+  groups = panel_utils_list_workspace_groups_for_monitor (plugin->screen, monitor);
+
   /* decrease the number of workspaces */
-  workspace = g_list_last (xfw_workspace_group_list_workspaces (plugin->workspace_group))->data;
+  workspace = g_list_last (xfw_workspace_group_list_workspaces (g_list_last (groups)->data))->data;
   xfw_workspace_remove (workspace, NULL);
+
+  g_list_free (groups);
 }
 
 
@@ -1374,13 +1398,19 @@ window_menu_plugin_menu_new (WindowMenuPlugin *plugin)
       XfwWorkspaceGroupCapabilities gcapabilities;
       XfwWorkspaceCapabilities wcapabilities;
 
+      /* adding/removing workspaces is also available on wayland and it seems reasonable
+       * to do it on the last workspace group for the monitor the plugin is on;
+       * see also: window_menu_plugin_workspace_add/remove() */
+      GdkMonitor *monitor = panel_utils_get_monitor_at_widget (GTK_WIDGET (plugin));
+      GList *groups = panel_utils_list_workspace_groups_for_monitor (plugin->screen, monitor);
+
       mi = gtk_separator_menu_item_new ();
       gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
       gtk_widget_show (mi);
 
       mi = panel_image_menu_item_new_with_label (_("Add Workspace"));
       gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
-      gcapabilities = xfw_workspace_group_get_capabilities (plugin->workspace_group);
+      gcapabilities = xfw_workspace_group_get_capabilities (g_list_last (groups)->data);
       gtk_widget_set_sensitive (mi, gcapabilities & XFW_WORKSPACE_GROUP_CAPABILITIES_CREATE_WORKSPACE);
       g_signal_connect (G_OBJECT (mi), "activate",
                         G_CALLBACK (window_menu_plugin_workspace_add), plugin);
@@ -1406,18 +1436,20 @@ window_menu_plugin_menu_new (WindowMenuPlugin *plugin)
 
       mi = panel_image_menu_item_new_with_label (label);
       gtk_menu_shell_append (GTK_MENU_SHELL (menu), mi);
-      wcapabilities = xfw_workspace_get_capabilities (g_list_last (workspaces)->data);
+      workspace = g_list_last (xfw_workspace_group_list_workspaces (g_list_last (groups)->data))->data;
+      wcapabilities = xfw_workspace_get_capabilities (workspace);
       gtk_widget_set_sensitive (mi, n_workspaces > 1 && wcapabilities & XFW_WORKSPACE_CAPABILITIES_REMOVE);
       g_signal_connect (G_OBJECT (mi), "activate",
                         G_CALLBACK (window_menu_plugin_workspace_remove), plugin);
       gtk_widget_show (mi);
 
-      g_free (label);
-      g_free (utf8);
-
       image = gtk_image_new_from_icon_name ("list-remove", GTK_ICON_SIZE_MENU);
       panel_image_menu_item_set_image (mi, image);
       gtk_widget_show (mi);
+
+      g_free (label);
+      g_free (utf8);
+      g_list_free (groups);
     }
 
   pango_font_description_free (italic);
